@@ -1,4 +1,4 @@
-set rcsId {$Id: combobut.tcl,v 1.39 1998/04/13 18:22:21 jfontain Exp $}
+set rcsId {$Id: combobut.tcl,v 1.40 1998/09/19 19:38:46 jfontain Exp $}
 
 class comboButton {}
 
@@ -82,7 +82,6 @@ proc comboButton::set-borderwidth {this value} {
 
 proc comboButton::popupListBox {this} {
     set shellPath $composite::($this,shell,path)
-    wm deiconify $shellPath
     if {[winfo exists $composite::($this,-reference)]} {
         set path $composite::($this,-reference)
         set border 0                           ;# use reference widget width eventually without including highlight border thickness
@@ -96,7 +95,7 @@ proc comboButton::popupListBox {this} {
     if {$x<0} {
         set x 0
     }
-    wm geometry $shellPath +$x+[expr {[winfo rooty $path]+[winfo height $path]}]
+    showTopLevel $shellPath +$x+[expr {[winfo rooty $path]+[winfo height $path]}]
     update idletasks
     raise $shellPath
     grab -global $shellPath
