@@ -2,7 +2,7 @@
 # the next line restarts using the interpreter \
 exec tclsh "$0" "$@"
 
-# $Id: instapkg.tcl,v 1.4 1997/06/05 12:11:44 jfontain Exp $
+# $Id: instapkg.tcl,v 1.6 1998/10/01 21:18:05 jfontain Exp $
 
 if {[llength $argv]!=1} {
     puts stderr "usage: $argv0 directory"
@@ -22,12 +22,12 @@ if {![file exists $directory]} {
     exit 1
 }
 
-if {[catch {package require stooop 3.0} message]} {
+if {[catch {package require stooop 3.6.1} message]} {
     puts stderr "stooop package must be installed first: $message"
     exit 1
 }
 
-if {[catch {eval file copy -force {pkgIndex.tcl scwoop.tcl arrowbut.tcl combobut.tcl comboent.tcl scrolist.tcl scroller.tcl notebook.tcl bindings.tcl labelfra.tcl confint.tcl panner.tcl spinent.tcl widgetip.tcl optimenu.tcl} {$directory}} message]} {
+if {[catch {eval file copy -force {pkgIndex.tcl scwoop.tcl arrowbut.tcl combobut.tcl comboent.tcl scrolist.tcl scroller.tcl notebook.tcl bindings.tcl labelfra.tcl confint.tcl panner.tcl spinent.tcl widgetip.tcl optimenu.tcl scwoutil.tcl scroll.tcl} {$directory}} message]} {
     puts stderr $message
     exit 1
 }
