@@ -1,4 +1,4 @@
-set rcsId {$Id: optimenu.tcl,v 1.26 1998/04/13 18:23:18 jfontain Exp $}
+set rcsId {$Id: optimenu.tcl,v 1.27 1998/09/19 19:38:46 jfontain Exp $}
 
 class optionMenu {}
 
@@ -87,8 +87,7 @@ proc optionMenu::set-choices {this value} {
         incr index
     }
     grid columnconfigure $widget::($this,path) 0 -minsize $width                 ;# find maximum width and apply it to visible label
-    wm deiconify $path
-    wm geometry $path 0x0                                       ;# make sure sizes will be correct the first time choices are popped
+    showTopLevel $path 0x0                                      ;# make sure sizes will be correct the first time choices are popped
     update idletasks
     wm withdraw $path
     wm geometry $path {}
@@ -139,10 +138,9 @@ proc optionMenu::popChoices {this} {
     if {$y<0} {
         set y 0
     }
-    wm deiconify $shellPath
-    wm geometry $shellPath +$x+$y
     # make sure choices width is identical to label width
-    wm geometry $shellPath [expr {[winfo width $labelPath]+(2*$widget::(default,MenuBorderWidth))}]x[winfo reqheight $shellPath]
+    showTopLevel $shellPath\
+        [expr {[winfo width $labelPath]+(2*$widget::(default,MenuBorderWidth))}]x[winfo reqheight $shellPath]+$x+$y
     update idletasks
     raise $shellPath
 
