@@ -1,4 +1,4 @@
-set rcsId {$Id: scroller.tcl,v 1.20 1998/09/27 20:43:02 jfontain Exp $}
+set rcsId {$Id: scroller.tcl,v 1.21 1998/10/02 20:30:40 jfontain Exp $}
 
 class scroller {
 
@@ -12,6 +12,10 @@ class scroller {
 
     proc options {this} {
         return [list\
+            [list\
+                -elementborderwidth elementBorderWidth ElementBorderWidth\
+                $widget::(default,ScrollbarElementBorderWidth) $widget::(default,ScrollbarElementBorderWidth)\
+            ]\
             [list -height height Height 0 0]\
             [list -width width Width 0 0]\
             [list\
@@ -46,12 +50,8 @@ class scroller {
         bind $path <Configure> "$canvas configure -width %w -height %h -scrollregion {0 0 %w %h}"
     }
 
-    proc set-width {this value} {
-        composite::configure $composite::($this,base) -width $value
-    }
-
-    proc set-height {this value} {
-        composite::configure $composite::($this,base) -height $value
+    foreach option {-elementborderwidth -height -width} {
+        proc set$option {this value} "composite::configure \$composite::(\$this,base) $option \$value"
     }
 
     proc set-xscrollincrement {this value} {
