@@ -1,6 +1,6 @@
-set rcsId {$Id: stooop.tcl,v 3.58 1998/04/10 21:12:55 jfontain Exp $}
+set rcsId {$Id: stooop.tcl,v 3.63 1998/09/05 20:21:54 jfontain Exp $}
 
-package provide stooop 3.5
+package provide stooop 3.6.1
 
 catch {rename proc _proc}            ;# rename proc before it is overloaded, ignore error in case of multiple inclusion of this file
 
@@ -57,15 +57,15 @@ namespace eval ::stooop {
         # use local variable for identifier because new can be invoked recursively
         if {[scan $classOrId %u dummy]==0} {                                                            ;# first argument is a class
             set constructor ${classOrId}::[namespace tail $classOrId]                                   ;# generate constructor name
-            # generate fully qualified class namespace name
-            set fullName [namespace qualifiers [uplevel namespace which -command $constructor]]
             # we could detect here whether class was ever declared but that would prevent stooop packages to load properly, because
             # constructor would not be invoked and thus class source file never sourced
-            set fullClass([set id [incr newId]]) $fullName
             # invoke the constructor for the class with optional arguments in caller's variable context so that object creation is
             # transparent and that array names as constructor parameters work with a simple upvar
-            uplevel $constructor $id $args
-        } else {  ;# first argument is an object identifier (unsigned integer) , copy source object to new object of identical class
+            # note: if class is in a package, the class namespace code is loaded here, as the first object of the class is created
+            uplevel $constructor [set id [incr newId]] $args
+            # generate fully qualified class namespace name now that we are sure that class namespace code has been invoked
+            set fullClass($id) [namespace qualifiers [uplevel namespace which -command $constructor]]
+        } else {   ;# first argument is an object identifier (unsigned integer), copy source object to new object of identical class
             if {[catch {set fullClass([set id [incr newId]]) $fullClass($classOrId)}]} {
                 error "invalid object identifier $classOrId"
             }
@@ -368,7 +368,7 @@ _proc ::stooop::memberProcedureDeclaration {fullClass class procedure arguments
             _proc ${fullClass}::$procedure $arguments \
 "::variable {}
 $checkCode
-::eval \$${fullClass}::(\$this,_derived)::$procedure \[::lrange \[::info level 0\] 1 end\]
+::uplevel \$${fullClass}::(\$this,_derived)::$procedure \[::lrange \[::info level 0\] 1 end\]
 "
         } else {                                                                                      ;# regular virtual declaration
             # setup access to class data
@@ -383,9 +383,9 @@ $body
 "::variable {}
 $checkCode
 if {!\[::catch {::info body \$${fullClass}::(\$this,_derived)::$procedure}\]} {
-::return \[::eval \$${fullClass}::(\$this,_derived)::$procedure \[::lrange \[::info level 0\] 1 end\]\]
+::return \[::uplevel \$${fullClass}::(\$this,_derived)::$procedure \[::lrange \[::info level 0\] 1 end\]\]
 }
-::eval ${fullClass}::_$procedure \[::lrange \[::info level 0\] 1 end\]
+::uplevel ${fullClass}::_$procedure \[::lrange \[::info level 0\] 1 end\]
 "
         }
     } else {                                                                                              ;# non virtual declaration
@@ -445,14 +445,20 @@ if {[llength [array names ::env STOOOP*]]>0} {             ;# if one or more env
 
         catch {rename ::stooop::new ::stooop::_new}                              ;# gracefully handle multiple sourcing of this file
         _proc ::stooop::new {classOrId args} {           ;# use a new new procedure instead of adding debugging code to existing one
+            variable newId
             variable fullClass
             variable interface
 
             if {[scan $classOrId %u dummy]==0} {                                                        ;# first argument is a class
                 set constructor ${classOrId}::[namespace tail $classOrId]                               ;# generate constructor name
+                catch {$constructor}              ;# force loading in case class is in a package so namespace commands work properly
                 set fullName [namespace qualifiers [uplevel namespace which -command $constructor]]
+                # anticipate full class name storage in original new{} in order to avoid invalid object identifier error in
+                # checkProcedure{} when member procedure is invoked from within contructor, in which case full class name would
+                # have yet to be stored.
+                set fullClass([expr {$newId+1}]) $fullName                 ;# new identifier is really incremented in original new{}
             } else {                                                                       ;# first argument is an object identifier
-                set fullName $fullClass($classOrId)
+                set fullName $fullClass($classOrId)                         ;# class code, if from a package, must already be loaded
             }
             if {[info exists interface($fullName)]} {
                 error "class $fullName with pure virtual procedures should not be instanciated"
@@ -507,6 +513,7 @@ if {[llength [array names ::env STOOOP*]]>0} {             ;# if one or more env
 
         debugInformation class qualifiedClass procedure qualifiedProcedure this
         if {![info exists this]} return                                                    ;# static procedure, no checking possible
+        if {[string compare $procedure constructor]==0} return   ;# in constructor, checking useless since object is not yet created
         if {![info exists fullClass($this)]} {
             error "$this is not a valid object identifier"
         }
