@@ -1,4 +1,4 @@
-set rcsId {$Id: widgetip.tcl,v 1.31 1998/04/13 19:34:25 jfontain Exp $}
+set rcsId {$Id: widgetip.tcl,v 1.32 1998/09/19 19:38:46 jfontain Exp $}
 
 class widgetTip {
 
@@ -96,8 +96,7 @@ class widgetTip {
     proc show {this x y} {
         set path $widgetTip::(path)
         widget::configure $widgetTip::(label) -font $switched::($this,-font) -text $switched::($this,-text)      ;# update tip label
-        wm deiconify $path
-        wm geometry $path +$x+$y
+        showTopLevel $path +$x+$y
         update idletasks
         raise $path
     }
